==> rust-git-checks-v1.0.0.zip: rust-git-checks-v1.0.0/src/checks/reject_merges.rs <==
// Copyright 2016 Kitware, Inc.
//
// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
// option. This file may not be copied, modified, or distributed
// except according to those terms.

use super::super::*;

#[derive(Debug, Default, Clone, Copy)]
/// A check which denies merge commits, including octopus merges.
pub struct RejectMerges;

impl RejectMerges {
    /// Create a new check to reject merge commits.
    pub fn new() -> Self {
        RejectMerges {}
    }
}

impl Check for RejectMerges {
    fn name(&self) -> &str {
        "reject-merges"
    }

    fn check(&self, _: &CheckGitContext, commit: &Commit) -> Result<CheckResult> {
        let mut result = CheckResult::new();

        if commit.parents.len() > 1 {
            result.add_error(format!("commit {} not allowed; it is a merge commit.",
                                     commit.sha1_short));
        }

        Ok(result)
    }
}

#[cfg(test)]
mod tests {
    use super::RejectMerges;
    use super::super::test::*;

    static NO_MERGES_TOPIC: &'static str = "2fab950c4ace0584760e00caae1bb7913b07494e";
    static WITH_MERGES_TOPIC: &'static str = "92f545fa6c9326fe11dfb69c3ee01af285b595f4";
    static OCTOPUS_MERGES_TOPIC: &'static str = "4447a8eddbccac61daa6b55642e46156011d36cb";

    #[test]
    fn test_reject_merges_no_merges() {
        let check = RejectMerges::new();
        let mut conf = GitCheckConfiguration::new();

        conf.add_check(&check);

        let result = test_check("test_reject_merges_no_merges", NO_MERGES_TOPIC, &conf);

        assert_eq!(result.warnings().len(), 0);
        assert_eq!(result.alerts().len(), 0);
        assert_eq!(result.errors().len(), 0);
        assert_eq!(result.allowed(), false);
        assert_eq!(result.pass(), true);
    }

    #[test]
    fn test_reject_merges_with_merges() {
        let check = RejectMerges::new();
        let mut conf = GitCheckConfiguration::new();

        conf.add_check(&check);

        let result = test_check("test_reject_merges_with_merges", WITH_MERGES_TOPIC, &conf);

        assert_eq!(result.warnings().len(), 0);
        assert_eq!(result.alerts().len(), 0);
        assert_eq!(result.errors().len(), 1);
        assert_eq!(result.errors()[0],
                   "commit 92f545f not allowed; it is a merge commit.");
        assert_eq!(result.allowed(), false);
        assert_eq!(result.pass(), false);
    }

    #[test]
    fn test_reject_merges_octopus_merges() {
        let check = RejectMerges::new();
        let mut conf = GitCheckConfiguration::new();

        conf.add_check(&check);

        let result = test_check("test_reject_merges_no_merges", OCTOPUS_MERGES_TOPIC, &conf);

        assert_eq!(result.warnings().len(), 0);
        assert_eq!(result.alerts().len(), 0);
        assert_eq!(result.errors().len(), 1);
        assert_eq!(result.errors()[0],
                   "commit 4447a8e not allowed; it is a merge commit.");
        assert_eq!(result.allowed(), false);
        assert_eq!(result.pass(), false);
    }
}

==> rust-git-checks-v2.3.0.zip: rust-git-checks-v2.3.0/src/checks/reject_merges.rs <==
// Copyright 2016 Kitware, Inc.
//
// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
// option. This file may not be copied, modified, or distributed
// except according to those terms.

use impl_prelude::*;

#[derive(Debug, Default, Clone, Copy)]
/// A check which denies merge commits, including octopus merges.
pub struct RejectMerges;

impl RejectMerges {
    /// Create a new check to reject merge commits.
    pub fn new() -> Self {
        RejectMerges {}
    }
}

impl Check for RejectMerges {
    fn name(&self) -> &str {
        "reject-merges"
    }

    fn check(&self, _: &CheckGitContext, commit: &Commit) -> Result<CheckResult> {
        let mut result = CheckResult::new();

        if commit.parents.len() > 1 {
            result.add_error(format!("commit {} not allowed; it is a merge commit.", commit.sha1));
        }

        Ok(result)
    }
}

#[cfg(test)]
mod tests {
    use checks::RejectMerges;
    use checks::test::*;

    static NO_MERGES_TOPIC: &'static str = "2fab950c4ace0584760e00caae1bb7913b07494e";
    static WITH_MERGES_TOPIC: &'static str = "92f545fa6c9326fe11dfb69c3ee01af285b595f4";
    static OCTOPUS_MERGES_TOPIC: &'static str = "4447a8eddbccac61daa6b55642e46156011d36cb";

    #[test]
    fn test_reject_merges_no_merges() {
        let check = RejectMerges::new();
        let mut conf = GitCheckConfiguration::new();

        conf.add_check(&check);

        let result = test_check("test_reject_merges_no_merges", NO_MERGES_TOPIC, &conf);

        assert_eq!(result.warnings().len(), 0);
        assert_eq!(result.alerts().len(), 0);
        assert_eq!(result.errors().len(), 0);
        assert_eq!(result.temporary(), false);
        assert_eq!(result.allowed(), false);
        assert_eq!(result.pass(), true);
    }

    #[test]
    fn test_reject_merges_with_merges() {
        let check = RejectMerges::new();
        let mut conf = GitCheckConfiguration::new();

        conf.add_check(&check);

        let result = test_check("test_reject_merges_with_merges", WITH_MERGES_TOPIC, &conf);

        assert_eq!(result.warnings().len(), 0);
        assert_eq!(result.alerts().len(), 0);
        assert_eq!(result.errors().len(), 1);
        assert_eq!(result.errors()[0],
                   "commit 92f545fa6c9326fe11dfb69c3ee01af285b595f4 not allowed; it is a merge \
                    commit.");
        assert_eq!(result.temporary(), false);
        assert_eq!(result.allowed(), false);
        assert_eq!(result.pass(), false);
    }

    #[test]
    fn test_reject_merges_octopus_merges() {
        let check = RejectMerges::new();
        let mut conf = GitCheckConfiguration::new();

        conf.add_check(&check);

        let result = test_check("test_reject_merges_no_merges", OCTOPUS_MERGES_TOPIC, &conf);

        assert_eq!(result.warnings().len(), 0);
        assert_eq!(result.alerts().len(), 0);
        assert_eq!(result.errors().len(), 1);
        assert_eq!(result.errors()[0],
                   "commit 4447a8eddbccac61daa6b55642e46156011d36cb not allowed; it is a merge \
                    commit.");
        assert_eq!(result.temporary(), false);
        assert_eq!(result.allowed(), false);
        assert_eq!(result.pass(), false);
    }
}
